"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useListingFilterProvider = exports.useFilterController = exports.ListingFilterProvider = void 0;
// Core logic for managing filters
const react_1 = __importDefault(require("react"));
const react_2 = require("react");
const ListingContext = (0, react_2.createContext)({});
function ListingFilterProvider({ children, }) {
    const [filterStates, setFilterStates] = (0, react_2.useState)({});
    const onFilterChange = (0, react_2.useCallback)((name, value) => setFilterStates((p) => (Object.assign(Object.assign({}, p), { [name]: value }))), [setFilterStates]);
    const getFilterState = (0, react_2.useCallback)((n) => {
        const item = filterStates[n];
        if (item)
            return item === null || item === void 0 ? void 0 : item.value;
        else
            return null;
    }, [filterStates]);
    const getCurrentFilterQuery = (0, react_2.useCallback)(() => ({
        and: Object.values(filterStates).reduce((p, c) => [
            ...p,
            c.queryFunc(c.value),
        ], []),
    }), [filterStates]);
    const removeFilter = (0, react_2.useCallback)((name) => {
        setFilterStates((pS) => {
            var _a;
            return (_a = Object === null || Object === void 0 ? void 0 : Object.keys(pS)) === null || _a === void 0 ? void 0 : _a.filter((n) => n !== name).reduce((p, c) => {
                return Object.assign(Object.assign({}, p), { [c]: pS[c] });
            }, {});
        });
    }, [setFilterStates]);
    return (react_1.default.createElement(ListingContext.Provider, { value: {
            getCurrentFilterQuery,
            onFilterChange,
            getFilterState,
            removeFilter,
            filterStates,
        } }, children));
}
exports.ListingFilterProvider = ListingFilterProvider;
function useFilterController({ queryFunc, name, }) {
    const { onFilterChange, getFilterState, removeFilter } = useListingFilterProvider();
    return {
        onChange: (v) => onFilterChange(name, { value: v, queryFunc }),
        resetFilter: () => removeFilter(name),
        value: getFilterState(name),
    };
}
exports.useFilterController = useFilterController;
function useListingFilterProvider() {
    return (0, react_2.useContext)(ListingContext);
}
exports.useListingFilterProvider = useListingFilterProvider;
//# sourceMappingURL=ListingFilterCore.js.map